@@ -260,6 +260,7 @@ eel_mime_add_application (const char *mime_type,
 		ret = NULL;
 	}
 
+        g_free (desktop_text);
 	g_free (basename);
 	g_free (filename);
 	g_free (application_dir);
@@ -594,7 +595,6 @@ eel_mime_set_default_application (const char *mime_type,
 			ret = (g_io_channel_write_chars (temp, line, 
 							 strlen (line), 
 							 NULL, NULL) == G_IO_STATUS_NORMAL);
-			
 			have_newline = (line[terminator_pos] == '\n');
 
 			g_free (line);
@@ -608,13 +608,14 @@ eel_mime_set_default_application (const char *mime_type,
 	} else {
 		const char *content;
 		
-		content = "[MIME Cache]\n";
+		content = "[Default Applications]\n";
 
 		ret = (g_io_channel_write_chars (temp, content, strlen (content), NULL, NULL) == G_IO_STATUS_NORMAL);
 	}
 
 	new_line = g_strdup_printf ("%s=%s\n", mime_type, id);
 	ret = (g_io_channel_write_chars (temp, new_line, strlen (new_line), NULL, NULL) == G_IO_STATUS_NORMAL);
+	g_free (new_line);
 
 	g_io_channel_unref (temp);
 	
